# Build Utilities

_WIP: Document build utilities._

## Requirements

* Python 2.7+ or 3.5+

## Installation

Install via pip:

```bash
pip install --upgrade -e path/to/lib
```

## Usage

After installation, the package can be imported:

```python
import build_py
```
